object
======
.. NOTE::
    This class is not intended for use by those using Pika in their applications. This documentation is for those who are extending Pika or otherwise working on the driver itself.

The class in this module, object.Object_ extends Python's object class creating a base class that other classes, who would like an easy to implement representation of the class state, may extend.

.. automodule:: object


object_
-------

.. autoclass:: object_
   :members:
   :member-order: bysource
   :private-members: True
   :undoc-members:
   :inherited-members:

Class
-----
.. autoclass:: Class
   :members:
   :inherited-members:
   :member-order: bysource
   :private-members: True
   :undoc-members:

Method
------
.. autoclass:: Method
   :members:
   :inherited-members:
   :member-order: bysource
   :private-members: True
   :undoc-members:

Properties
----------
.. autoclass:: Properties
   :members:
   :inherited-members:
   :member-order: bysource
   :private-members: True
   :undoc-members:
